.. module:: pymeasure.instruments.novanta

#################
Novanta Photonics
#################

This section contains specific documentation on the Novanta photonics instruments that are implemented.
Novanta contains also Lasers developed by Laserquantum.
If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

.. toctree::
   :maxdepth: 2

   fpu60
